unit main;

interface

uses
  Forms, BFBaseComponent, BFDiscovery, Menus, Classes, Controls, ComCtrls;

type
  TfmMain = class(TForm)
    MainMenu: TMainMenu;
    miFile: TMenuItem;
    miFileExit: TMenuItem;
    miView: TMenuItem;
    miViewRefresh: TMenuItem;
    miHelp: TMenuItem;
    miHelpAbout: TMenuItem;
    lvDiscovery: TListView;
    miSelectDevice: TMenuItem;
    N1: TMenuItem;
    lvMonitoring: TListView;
    miFileStartMonitoring: TMenuItem;
    miFileStopMonitoring: TMenuItem;
    N2: TMenuItem;
    BFDiscovery: TBFDiscovery;
    procedure miHelpAboutClick(Sender: TObject);
    procedure miFileExitClick(Sender: TObject);
    procedure miViewRefreshClick(Sender: TObject);
    procedure miSelectDeviceClick(Sender: TObject);
    procedure miFileStartMonitoringClick(Sender: TObject);
    procedure miFileStopMonitoringClick(Sender: TObject);
    procedure BFDiscoveryFound(Sender: TObject; Device: TBFDevice);
    procedure BFDiscoveryLost(Sender: TObject; Device: TBFDevice);
  end;

var
  fmMain: TfmMain = nil;

implementation

uses
  SysUtils;

{$R *.dfm}

procedure TfmMain.miHelpAboutClick(Sender: TObject);
begin
  BFDiscovery.ShowAbout;
end;

procedure TfmMain.miFileExitClick(Sender: TObject);
begin
  Close;
end;

procedure TfmMain.miViewRefreshClick(Sender: TObject);
var
  DevList: TBFDeviceList;
  Loop: Integer;
  Loop1: Integer;
begin
  BFDiscovery.Discovery(DevList);

  with lvDiscovery.Items do begin
    BeginUpdate;

    Clear;

    for Loop := 0 to DevList.Count - 1 do begin
      with Add do begin
        Caption := DevList[Loop].Name;

        SubItems.Add(DevList[Loop].Address);
        SubItems.Add(BoolToStr(DevList[Loop].Authenticated, True));
        SubItems.Add(BoolToStr(DevList[Loop].Connected, True));
        SubItems.Add('$' + IntToHex(DevList[Loop].ClassOfDevice, 8));
        SubItems.Add(DateTimeToStr(DevList[Loop].LastSeen));
        SubItems.Add(DateTimeToStr(DevList[Loop].LastUsed));
        SubItems.Add(BoolToStr(DevList[Loop].Remembered, True));
      end;

      for Loop1 := 0 to DevList[Loop].Services.Count - 1 do
       with Add do begin
         Caption := '';
         SubItems.Add(DevList[Loop].Services[Loop1].Name);
         SubItems.Add(DevList[Loop].Services[Loop1].Comment);
       end;

    end;

    EndUpdate;
  end;

  DevList.Free;
end;

procedure TfmMain.miSelectDeviceClick(Sender: TObject);
var
  Device: TBFDevice;
begin
  Device := BFDiscovery.SelectDevice(True);

  if Assigned(Device) then Device.Free;
end;

procedure TfmMain.miFileStartMonitoringClick(Sender: TObject);
begin
  BFDiscovery.StartMonitoring;

  miFileStartMonitoring.Enabled := False;
  miFileStopMonitoring.Enabled := True;
end;

procedure TfmMain.miFileStopMonitoringClick(Sender: TObject);
begin
  BFDiscovery.StopMonitoring;

  miFileStartMonitoring.Enabled := True;
  miFileStopMonitoring.Enabled := False;
end;

procedure TfmMain.BFDiscoveryFound(Sender: TObject; Device: TBFDevice);
begin
  with lvMonitoring.Items do begin
    BeginUpdate;

    with Add do begin
      Caption := 'Found';
      SubItems.Add(Device.Name);
      SubItems.Add(Device.Address);
      SubItems.Add(BoolToStr(Device.Authenticated, True));
      SubItems.Add('$' + IntToHex(Device.ClassOfDevice, 8));
      SubItems.Add(DateTimeToStr(Device.LastSeen));
      SubItems.Add(DateTimeToStr(Device.LastUsed));
      SubItems.Add(BoolToStr(Device.Remembered, True));
    end;

    EndUpdate;
  end;
end;

procedure TfmMain.BFDiscoveryLost(Sender: TObject; Device: TBFDevice);
begin
  with lvMonitoring.Items do begin
      BeginUpdate;

    with Add do begin
      Caption := 'Lost';
      SubItems.Add(Device.Name);
      SubItems.Add(Device.Address);
      SubItems.Add(BoolToStr(Device.Authenticated, True));
      SubItems.Add('$' + IntToHex(Device.ClassOfDevice, 8));
      SubItems.Add(DateTimeToStr(Device.LastSeen));
      SubItems.Add(DateTimeToStr(Device.LastUsed));
      SubItems.Add(BoolToStr(Device.Remembered, True));
    end;

    EndUpdate;
  end;
end;

end.
