unit main;

interface

uses
  Forms, BFBaseComponent, BFClient, Menus, Classes, ActnList, ComCtrls,
  Controls, ExtCtrls;

type
  TfmMain = class(TForm)
    MainMenu: TMainMenu;
    miFile: TMenuItem;
    miHelp: TMenuItem;
    miHelpAbout: TMenuItem;
    miFileExit: TMenuItem;
    TreeView: TTreeView;
    Splitter: TSplitter;
    ListView: TListView;
    miFileConnect: TMenuItem;
    miFileDisconnect: TMenuItem;
    N1: TMenuItem;
    ActionList: TActionList;
    acCreateFolder: TAction;
    acDeleteFolder: TAction;
    acDeleteFile: TAction;
    acUpload: TAction;
    acDownload: TAction;
    miFileCreateFolder: TMenuItem;
    N2: TMenuItem;
    miFileDeleteFolder: TMenuItem;
    miFileDeleteFile: TMenuItem;
    N3: TMenuItem;
    N4: TMenuItem;
    miFileUpload: TMenuItem;
    miFileDownload: TMenuItem;
    PopupMenu1: TPopupMenu;
    Createfolder1: TMenuItem;
    Deletefolder1: TMenuItem;
    PopupMenu2: TPopupMenu;
    Deletefile1: TMenuItem;
    Upload1: TMenuItem;
    Download1: TMenuItem;
    ProgressBar1: TProgressBar;
    BFFileTransferClient: TBFFileTransferClient;
    procedure miHelpAboutClick(Sender: TObject);
    procedure miFileExitClick(Sender: TObject);
    procedure miFileConnectClick(Sender: TObject);
    procedure miFileDisconnectClick(Sender: TObject);
    procedure TreeViewChange(Sender: TObject; Node: TTreeNode);
    procedure acCreateFolderUpdate(Sender: TObject);
    procedure acDeleteFolderUpdate(Sender: TObject);
    procedure acDeleteFileUpdate(Sender: TObject);
    procedure acUploadUpdate(Sender: TObject);
    procedure acDownloadUpdate(Sender: TObject);
    procedure acCreateFolderExecute(Sender: TObject);
    procedure acDeleteFolderExecute(Sender: TObject);
    procedure acDeleteFileExecute(Sender: TObject);
    procedure acUploadExecute(Sender: TObject);
    procedure acDownloadExecute(Sender: TObject);
    procedure BFFileTransferClientProgress(Sender: TObject; ObjectName: String; ObjectIndex, ObjectTotal, Position, Size: Cardinal; var Abort: Boolean);
  end;

var
  fmMain: TfmMain = nil;

implementation

uses
  SysUtils, Dialogs, devsel, BFAPI;

{$R *.dfm}

procedure TfmMain.miHelpAboutClick(Sender: TObject);
begin
  BFFileTransferClient.ShowAbout;
end;

procedure TfmMain.miFileExitClick(Sender: TObject);
begin
  Close;
end;

procedure TfmMain.miFileConnectClick(Sender: TObject);
var
  DoOpen: Boolean;
begin
  DoOpen := False;

  with TfmDevSel.Create(Self) do begin
    if ShowModal = mrOK then begin
      DoOpen := True;

      with BFFileTransferClient do
        case PageControl.ActivePageIndex of
          0: begin
               Transport := btBluetooth;
               BluetoothTransport.Address := edBluetoothAddress.Text;
             end;

          1: begin
               Transport := btIrDA;
               IrDATransport.Address := edIrDAAddress.Text;
             end;

          2: begin
               Transport := btCOMPort;
               COMPortTransport.Port := StrToInt(edPort.Text);
               COMPortTransport.InitCommand := edInitString.Text;
             end;
        end;
    end;

    Free;
  end;

  if DoOpen then begin
    BFFileTransferClient.Open;
    case BFFileTransferClient.Transport of
      btBluetooth: TreeView.Items.Add(nil, BFFileTransferClient.BluetoothTransport.RemoteName);
      btIrDA: TreeView.Items.Add(nil, BFFileTransferClient.IrDATransport.RemoteName);
      btCOMPort: TreeView.Items.Add(nil, 'COMPort device');
    end;

    miFileDisconnect.Enabled := True;
    miFileConnect.Enabled := False;

    TreeView.Selected := TreeView.Items[0];
  end;
end;

procedure TfmMain.miFileDisconnectClick(Sender: TObject);
begin
  BFFileTransferClient.Close;

  miFileDisconnect.Enabled := False;
  miFileConnect.Enabled := True;
end;

procedure TfmMain.TreeViewChange(Sender: TObject; Node: TTreeNode);
var
  Selected: TTreeNode;
  ANode: TTreeNode;
  Path: TStringList;
  Files: TBFFileList;
  Loop: Integer;
begin
  Selected := TreeView.Selected;

  if Assigned(Selected) then begin
    Selected.DeleteChildren;
    ListView.Items.Clear;

    Path := TStringList.Create;

    try
      ANode := Selected;
      while Assigned(ANode.Parent) do begin
        Path.Add(ANode.Text);
        ANode := ANode.Parent;
      end;

      try
        BFFileTransferClient.SetPath;
        for Loop := Path.Count - 1 downto 0 do BFFileTransferClient.SetPath(Path[Loop]);
      except
      end;

      Files := BFFileTransferClient.Dir;

      try
        for Loop := 0 to Files.Count - 1 do
          if Files[Loop].IsFolder then
            TreeView.Items.AddChild(Selected, Files[Loop].Name)
          else
            with ListView.Items.Add do begin
              Caption := Files[Loop].Name;
              SubItems.Add(IntToStr(Files[Loop].Size));
            end;

        if Selected.HasChildren then Selected.Expand(False);
      finally
        Files.Free;
      end;
    finally
      Path.Free;
    end;
  end;
end;

procedure TfmMain.acCreateFolderUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := Assigned(TreeView.Selected) and BFFileTransferClient.Active;
end;

procedure TfmMain.acDeleteFolderUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := Assigned(TreeView.Selected) and BFFileTransferClient.Active;
end;

procedure TfmMain.acDeleteFileUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := Assigned(ListView.Selected) and BFFileTransferClient.Active;
end;

procedure TfmMain.acUploadUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := Assigned(TreeView.Selected) and BFFileTransferClient.Active;
end;

procedure TfmMain.acDownloadUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := Assigned(ListView.Selected) and BFFileTransferClient.Active;
end;

procedure TfmMain.acCreateFolderExecute(Sender: TObject);
var
  AName: string;
begin
  if InputQuery('Create new folder', 'Folder name', AName) then begin
    BFFileTransferClient.SetPath(AName, True);
    TreeViewChange(TreeView, TreeView.Selected);
  end;
end;

procedure TfmMain.acDeleteFolderExecute(Sender: TObject);
begin
  if MessageDlg('Delete folder?', mtConfirmation, [mbYes, mbNo], 0) = mrYes then begin
    BFFileTransferClient.SetPath('..');
    BFFileTransferClient.Delete(TreeView.Selected.Text);
    TreeView.Selected := TreeView.Selected.Parent; 
  end;
end;

procedure TfmMain.acDeleteFileExecute(Sender: TObject);
begin
  if MessageDlg('Delete file?', mtConfirmation, [mbYes, mbNo], 0) = mrYes then begin
    BFFileTransferClient.Delete(ListView.Selected.Caption);
    TreeViewChange(TreeView, TreeView.Selected);
  end;
end;

procedure TfmMain.acUploadExecute(Sender: TObject);
var
  AName: string;
begin
  if PromptForFileName(AName) then begin
    BFFileTransferClient.Put(AName);
    TreeViewChange(TreeView, TreeView.Selected);

    ProgressBar1.Position := 0;
    ProgressBar1.Max := 0;
  end;
end;

procedure TfmMain.acDownloadExecute(Sender: TObject);
var
  Data: TBFByteArray;
  AFile: file of Byte;
  Loop: Integer;
begin
  BFFileTransferClient.Get(ListView.Selected.Caption, Data);

  ProgressBar1.Position := 0;
  ProgressBar1.Max := 0;

  AssignFile(AFile, ExtractFilePath(Application.ExeName) + ListView.Selected.Caption);
  Rewrite(AFile);

  for Loop := 0 to Length(Data) - 1 do Write(AFile, Data[Loop]);

  CloseFile(AFile);
end;

procedure TfmMain.BFFileTransferClientProgress(Sender: TObject; ObjectName: String; ObjectIndex, ObjectTotal, Position, Size: Cardinal; var Abort: Boolean);
begin
  ProgressBar1.Max := Size;
  ProgressBar1.Position := Position;
  Update;
  Application.ProcessMessages;
end;

end.
