unit main;

interface

uses
  Forms, Classes, ActnList, Menus, BFAuthenticator, BFBaseComponent,
  BFClient, StdCtrls, Controls, ExtCtrls, ComCtrls;

type
  TfmMain = class(TForm)
    BFSMSClient: TBFSMSClient;
    BFAuthenticator: TBFAuthenticator;
    MainMenu: TMainMenu;
    miFile: TMenuItem;
    miHelp: TMenuItem;
    miHelpAbout: TMenuItem;
    miFileClose: TMenuItem;
    ActionList: TActionList;
    acConnect: TAction;
    acDisconnect: TAction;
    acRead: TAction;
    acSend: TAction;
    miFileConnect: TMenuItem;
    miFileDisconnect: TMenuItem;
    N1: TMenuItem;
    miFileRead: TMenuItem;
    miFileSend: TMenuItem;
    N2: TMenuItem;
    ListView: TListView;
    acDelete: TAction;
    acResend: TAction;
    miEdit: TMenuItem;
    miEditDelete: TMenuItem;
    miEditResend: TMenuItem;
    Panel1: TPanel;
    Label1: TLabel;
    cbRead: TComboBox;
    Label2: TLabel;
    cbWrite: TComboBox;
    Label3: TLabel;
    cbReceive: TComboBox;
    procedure miHelpAboutClick(Sender: TObject);
    procedure miFileCloseClick(Sender: TObject);
    procedure acConnectUpdate(Sender: TObject);
    procedure acDisconnectUpdate(Sender: TObject);
    procedure acReadUpdate(Sender: TObject);
    procedure acSendUpdate(Sender: TObject);
    procedure acConnectExecute(Sender: TObject);
    procedure acDisconnectExecute(Sender: TObject);
    procedure acReadExecute(Sender: TObject);
    procedure acSendExecute(Sender: TObject);
    procedure acDeleteUpdate(Sender: TObject);
    procedure acResendUpdate(Sender: TObject);
    procedure acDeleteExecute(Sender: TObject);
    procedure acResendExecute(Sender: TObject);
    procedure cbReadChange(Sender: TObject);
    procedure cbWriteChange(Sender: TObject);
    procedure cbReceiveChange(Sender: TObject);
  end;

var
  fmMain: TfmMain = nil;

implementation

uses
  SysUtils, newsms, Dialogs, devsel, BFAPI;

{$R *.dfm}

procedure TfmMain.miHelpAboutClick(Sender: TObject);
begin
  BFSMSClient.ShowAbout;
end;

procedure TfmMain.miFileCloseClick(Sender: TObject);
begin
  Close;
end;

procedure TfmMain.acConnectUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := not BFSMSClient.Active;
end;

procedure TfmMain.acDisconnectUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := BFSMSClient.Active;
end;

procedure TfmMain.acReadUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := BFSMSClient.Active;
end;

procedure TfmMain.acSendUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := BFSMSClient.Active;
end;

procedure TfmMain.acConnectExecute(Sender: TObject);
var
  DoOpen: Boolean;
begin
  DoOpen := False;

  with TfmDevSel.Create(Self) do begin
    if ShowModal = mrOK then begin
      DoOpen := True;

      with BFSMSClient do
        case PageControl.ActivePageIndex of
          0: begin
               Transport := btBluetooth;
               BluetoothTransport.Address := edBluetoothAddress.Text;
             end;

          1: begin
               Transport := btIrDA;
               IrDATransport.Address := edIrDAAddress.Text;
             end;

          2: begin
               Transport := btCOMPort;
               COMPortTransport.Port := StrToInt(edPort.Text);
               COMPortTransport.InitCommand := edInitString.Text;
             end;
        end;
    end;

    Free;
  end;

  if DoOpen then begin
    BFSMSClient.Open;

    with cbRead do begin
      Enabled := True;
      Items.Clear;
      if mmBoth in BFSMSClient.SupportedMemories[mmtReadDelete] then Items.Add('Both');
      if mmMobile in BFSMSClient.SupportedMemories[mmtReadDelete] then Items.Add('Mobile');
      if mmSIM in BFSMSClient.SupportedMemories[mmtReadDelete] then Items.Add('SIM');
      case BFSMSClient.PrefferedMemory[mmtReadDelete] of
        mmBoth: ItemIndex := 0;
        mmMobile: ItemIndex := 1;
        mmSIM: ItemIndex := 2;
      end;
    end;

    with cbWrite do begin
      Enabled := True;
      Items.Clear;
      if mmBoth in BFSMSClient.SupportedMemories[mmtWriteSend] then Items.Add('Both');
      if mmMobile in BFSMSClient.SupportedMemories[mmtWriteSend] then Items.Add('Mobile');
      if mmSIM in BFSMSClient.SupportedMemories[mmtWriteSend] then Items.Add('SIM');
      case BFSMSClient.PrefferedMemory[mmtWriteSend] of
        mmBoth: ItemIndex := 0;
        mmMobile: ItemIndex := 1;
        mmSIM: ItemIndex := 2;
      end;
    end;

    with cbReceive do begin
      Enabled := True;
      Items.Clear;
      if mmBoth in BFSMSClient.SupportedMemories[mmtReceive] then Items.Add('Both');
      if mmMobile in BFSMSClient.SupportedMemories[mmtReceive] then Items.Add('Mobile');
      if mmSIM in BFSMSClient.SupportedMemories[mmtReceive] then Items.Add('SIM');
      case BFSMSClient.PrefferedMemory[mmtReceive] of
        mmBoth: ItemIndex := 0;
        mmMobile: ItemIndex := 1;
        mmSIM: ItemIndex := 2;
      end;
    end;
  end;
end;

procedure TfmMain.acDisconnectExecute(Sender: TObject);
begin
  BFSMSClient.Close;

  cbRead.Enabled := False;
  cbWrite.Enabled := False;
  cbReceive.Enabled := False;
end;

procedure TfmMain.acReadExecute(Sender: TObject);
var
  List: TBFSMSList;
  Loop: Integer;
  SMS: TBFSMS;
begin
  List := TBFSMSList.Create;
  BFSMSClient.ReadSMS(mtAll, List);

  with ListView.Items do begin
    BeginUpdate;
    Clear;

    for Loop := 0 to List.Count - 1 do begin
      SMS := List[Loop];

      with Add do begin
        if SMS.Date = 0 then
          Caption := ''
        else
          Caption := DateTimeToStr(SMS.Date);
        SubItems.Add(IntToStr(SMS.Index));
        SubItems.Add(IntToStr(SMS.Reference));
        SubItems.Add(SMS.Phone);
        SubItems.Add(SMS.ServiceCenter);
        case SMS.SMSType of
          mtRecUnread: SubItems.Add('Received unread');
          mtRecRead: SubItems.Add('Received read');
          mtStoUnsent: SubItems.Add('Stored unsent');
          mtStoSent: SubItems.Add('Stored sent');
        end;
        case SMS.MTI of
          mtiDeliver: SubItems.Add('Deliver');
          mtiSubmit: SubItems.Add('Submit');
          mtiDeliverReport: SubItems.Add('Report');
        end;
        SubItems.Add(SMS.Text);
      end;
    end;

    EndUpdate;
  end;

  List.Free;
end;

procedure TfmMain.acSendExecute(Sender: TObject);
var
  Phone: string;
  SCA: string;
  Msg: string;
  Index: Integer;
  SMS: TBFSMS;
  MR: Byte;
begin
  with TfmNewSMS.Create(Self) do begin
    try
      if ShowModal = mrOK then begin
        Phone := edNumber.Text;
        SCA := edSCA.Text;
        Msg := meMessage.Text;

        if cbSend.Checked then begin
          MR := BFSMSClient.SendSMS(SCA, Phone, Msg);
          ShowMessage('Reference: ' + IntToStr(MR));

        end else begin
          Index := BFSMSClient.SaveSMS(SCA, Phone, Msg);
          BFSMSClient.ReadSMS(Index, SMS);

          with ListView.Items.Add do begin
            if SMS.Date = 0 then
              Caption := ''
            else
              Caption := DateTimeToStr(SMS.Date);
            SubItems.Add(IntToStr(SMS.Index));
            SubItems.Add(IntToStr(SMS.Reference));
            SubItems.Add(SMS.Phone);
            SubItems.Add(SMS.ServiceCenter);
            case SMS.SMSType of
              mtRecUnread: SubItems.Add('Received unread');
              mtRecRead: SubItems.Add('Received read');
              mtStoUnsent: SubItems.Add('Stored unsent');
              mtStoSent: SubItems.Add('Stored sent');
            end;
            case SMS.MTI of
              mtiDeliver: SubItems.Add('Deliver');
              mtiSubmit: SubItems.Add('Submit');
              mtiDeliverReport: SubItems.Add('Report');
            end;
            SubItems.Add(SMS.Text);
          end;
        end;
      end;

    finally
      Free;
    end;
  end;
end;

procedure TfmMain.acDeleteUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := BFSMSClient.Active and Assigned(ListView.Selected);
end;

procedure TfmMain.acResendUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := BFSMSClient.Active and Assigned(ListView.Selected);
end;

procedure TfmMain.acDeleteExecute(Sender: TObject);
begin
  BFSMSClient.DeleteSMS(StrToInt(ListView.Selected.SubItems[0]));
  ListView.Selected.Delete;
end;

procedure TfmMain.acResendExecute(Sender: TObject);
var
  MR: Byte;
begin
  MR := BFSMSClient.SendSMS(StrToInt(ListView.Selected.SubItems[0]), ListView.Selected.SubItems[2]);
  ShowMessage('Reference: ' + IntToStr(MR));
end;

procedure TfmMain.cbReadChange(Sender: TObject);
begin
  if cbRead.Text = 'Both' then BFSMSClient.PrefferedMemory[mmtReadDelete] := mmBoth;
  if cbRead.Text = 'Mobile' then BFSMSClient.PrefferedMemory[mmtReadDelete] := mmMobile;
  if cbRead.Text = 'SIM' then BFSMSClient.PrefferedMemory[mmtReadDelete] := mmSIM;
end;

procedure TfmMain.cbWriteChange(Sender: TObject);
begin
  if cbWrite.Text = 'Both' then BFSMSClient.PrefferedMemory[mmtWriteSend] := mmBoth;
  if cbWrite.Text = 'Mobile' then BFSMSClient.PrefferedMemory[mmtWriteSend] := mmMobile;
  if cbWrite.Text = 'SIM' then BFSMSClient.PrefferedMemory[mmtWriteSend] := mmSIM;
end;

procedure TfmMain.cbReceiveChange(Sender: TObject);
begin
  if cbReceive.Text = 'Both' then BFSMSClient.PrefferedMemory[mmtReceive] := mmBoth;
  if cbReceive.Text = 'Mobile' then BFSMSClient.PrefferedMemory[mmtReceive] := mmMobile;
  if cbReceive.Text = 'SIM' then BFSMSClient.PrefferedMemory[mmtReceive] := mmSIM;
end;

end.
