unit main;

interface

uses
  Forms, BFClient, BFBaseComponent, BFAuthenticator, Menus, Classes,
  Controls, StdCtrls;

type
  TfmMain = class(TForm)
    MainMenu: TMainMenu;
    miFile: TMenuItem;
    miHelp: TMenuItem;
    miHelpAbout: TMenuItem;
    miFileClose: TMenuItem;
    miFileConnect: TMenuItem;
    miFileDisconnect: TMenuItem;
    N1: TMenuItem;
    Memo: TMemo;
    BFAuthenticator: TBFAuthenticator;
    BFSerialPortClient: TBFSerialPortClient;
    procedure miHelpAboutClick(Sender: TObject);
    procedure miFileCloseClick(Sender: TObject);
    procedure miFileDisconnectClick(Sender: TObject);
    procedure miFileConnectClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure MemoKeyDown(Sender: TObject; var Key: Word; Shift: TShiftState);
  end;

var
  fmMain: TfmMain = nil;

implementation

uses
  BFAPI, Windows, SysUtils, devsel;

{$R *.dfm}

procedure TfmMain.miHelpAboutClick(Sender: TObject);
begin
  BFSerialPortClient.ShowAbout;
end;

procedure TfmMain.miFileCloseClick(Sender: TObject);
begin
  Close;
end;

procedure TfmMain.miFileDisconnectClick(Sender: TObject);
begin
  BFSerialPortClient.Close;

  miFileDisconnect.Enabled := False;
  miFileConnect.Enabled := True;
end;

procedure TfmMain.miFileConnectClick(Sender: TObject);
var
  DoOpen: Boolean;
begin
  DoOpen := False;

  with TfmDevSel.Create(Self) do begin
    if ShowModal = mrOK then begin
      DoOpen := True;

      with BFSerialPortClient do
        case PageControl.ActivePageIndex of
          0: begin
               Transport := btBluetooth;
               BluetoothTransport.Address := edBluetoothAddress.Text;
             end;

          1: begin
               Transport := btIrDA;
               IrDATransport.Address := edIrDAAddress.Text;
             end;

          2: begin
               Transport := btCOMPort;
               COMPortTransport.Port := StrToInt(edPort.Text);
               COMPortTransport.InitCommand := edInitString.Text;
             end;
        end;
    end;

    Free;
  end;

  if DoOpen then begin
    BFSerialPortClient.Open;

    case BFSerialPortClient.Transport of
      btBluetooth: with BFSerialPortClient.BluetoothTransport do begin
                     Memo.Lines.Add('CONNECT');
                     Memo.Lines.Add('  Local address: ' + LocalAddress);
                     Memo.Lines.Add('  Local BT address: ' + IntToHex(LocalBTAddress, 12));
                     Memo.Lines.Add('  Local name: ' + LocalName);
                     Memo.Lines.Add('  Remote address: ' + RemoteAddress);
                     Memo.Lines.Add('  Remote BT address: ' + IntToHex(RemoteBTAddress, 12));
                     Memo.Lines.Add('  Remote name: ' + RemoteName);
                   end;

      btCOMPort: Memo.Lines.Add('CONNECT');

      btIrDA: with BFSerialPortClient.IrDATransport do begin
                Memo.Lines.Add('CONNECT');
                Memo.Lines.Add('  Remote address: ' + RemoteAddress);
                Memo.Lines.Add('  Remote BT address: ' + IntToHex(Integer(RemoteIrDAAddress), 6));
                Memo.Lines.Add('  Remote name: ' + RemoteName);
              end;
    end;

    miFileDisconnect.Enabled := True;
    miFileConnect.Enabled := False;
  end;
end;

procedure TfmMain.FormDestroy(Sender: TObject);
begin
  BFSerialPortClient.Close;
end;

procedure TfmMain.MemoKeyDown(Sender: TObject; var Key: Word; Shift: TShiftState);
var
  Str: string;
  Data: TBFByteArray;
  Size: Integer;
begin
  if BFSerialPortClient.Active and (Key = VK_RETURN) then begin
    Str := Memo.Lines[Memo.Lines.Count - 1];

    if Str <> '' then begin
      BFSerialPortClient.Write(TBFByteArray(Str + #$0D));
      SetLength(Data, 255);
      Size := 255;
      BFSerialPortClient.Read(Data, Size);
      Memo.Lines.Add(string(Data));
      SetLength(Data, 0);
    end;
  end;
end;

end.
