unit main;

interface

uses
  Forms, BFAuthenticator, BFDiscovery, BFBaseComponent, BFClient, Classes,
  Controls, StdCtrls, BFIrDADiscovery;

type
  TfmMain = class(TForm)
    BFSyncronizationClient: TBFSyncronizationClient;
    BFDiscovery: TBFDiscovery;
    Label1: TLabel;
    Label2: TLabel;
    BFIrDADiscovery: TBFIrDADiscovery;
    procedure BFDiscoveryFound(Sender: TObject; Device: TBFDevice);
    procedure FormCreate(Sender: TObject);
    procedure BFIrDADiscoveryFound(Sender: TObject; Device: TBFIrDADevice);
  end;

var
  fmMain: TfmMain = nil;

implementation

uses
  BFAPI;

{$R *.dfm}

procedure TfmMain.BFDiscoveryFound(Sender: TObject; Device: TBFDevice);
var
  List: TStringList;
begin
  List := TStringList.Create;
  try
    Label1.Caption := 'Device found: ' + Device.Name;
    with BFSyncronizationClient do begin
      Transport := btBluetooth;
      BluetoothTransport.Address := Device.Address;
    end;

    Label2.Caption := 'Connecting...';
    Update;
    Application.ProcessMessages;
    BFSyncronizationClient.Open;

    try
      Label2.Caption := 'Receiving Device Information Object';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadDevInfo(List);
      List.SaveToFile(Device.Name + '_devinfo.txt');
    except
    end;

    try
      Label2.Caption := 'Back-Up Calendar';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadCalendar(List);
      List.SaveToFile(Device.Name + '_cal.vcs');
    except
    end;

    try
      Label2.Caption := 'Back-Up Incoming Calls';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadIncomingCalls(List);
      List.SaveToFile(Device.Name + '_ich.vcf');
    except
    end;

    try
      Label2.Caption := 'Back-Up Incoming Messages';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadIncomingMessages(List);
      List.SaveToFile(Device.Name + '_inmsg.vmg');
    except
    end;

    try
      Label2.Caption := 'Back-Up Missed Calls';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadMissedCalls(List);
      List.SaveToFile(Device.Name + '_mch.vcf');
    except
    end;

    try
      Label2.Caption := 'Back-Up Outgoing Calls';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadOutgoingCalls(List);
      List.SaveToFile(Device.Name + '_och.vcf');
    except
    end;

    try
      Label2.Caption := 'Back-Up Outgoing Messages';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadOutgoingMessages(List);
      List.SaveToFile(Device.Name + '_outmsg.vmg');
    except
    end;

    try
      Label2.Caption := 'Back-Up Phone Book';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadPhoneBook(List);
      List.SaveToFile(Device.Name + '_pb.vcf');
    except
    end;

    BFSyncronizationClient.Close;
    Label1.Caption := 'Searching for device...';
    Label2.Caption := '';

  except
  end;

  List.Free;
end;

procedure TfmMain.FormCreate(Sender: TObject);
begin
  BFDiscovery.StartMonitoring;
  BFIrDADiscovery.StartMonitoring;
end;

procedure TfmMain.BFIrDADiscoveryFound(Sender: TObject; Device: TBFIrDADevice);
var
  List: TStringList;
begin
  List := TStringList.Create;
  try
    Label1.Caption := 'Device found: ' + Device.Name;
    with BFSyncronizationClient do begin
      Transport := btIrDA;
      IrDATransport.Address := Device.Address;
    end;

    Label2.Caption := 'Connecting...';
    Update;
    Application.ProcessMessages;
    BFSyncronizationClient.Open;

    try
      Label2.Caption := 'Receiving Device Information Object';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadDevInfo(List);
      List.SaveToFile(Device.Name + '_devinfo.txt');
    except
    end;

    try
      Label2.Caption := 'Back-Up Calendar';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadCalendar(List);
      List.SaveToFile(Device.Name + '_cal.vcs');
    except
    end;

    try
      Label2.Caption := 'Back-Up Incoming Calls';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadIncomingCalls(List);
      List.SaveToFile(Device.Name + '_ich.vcf');
    except
    end;

    try
      Label2.Caption := 'Back-Up Incoming Messages';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadIncomingMessages(List);
      List.SaveToFile(Device.Name + '_inmsg.vmg');
    except
    end;

    try
      Label2.Caption := 'Back-Up Missed Calls';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadMissedCalls(List);
      List.SaveToFile(Device.Name + '_mch.vcf');
    except
    end;

    try
      Label2.Caption := 'Back-Up Outgoing Calls';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadOutgoingCalls(List);
      List.SaveToFile(Device.Name + '_och.vcf');
    except
    end;

    try
      Label2.Caption := 'Back-Up Outgoing Messages';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadOutgoingMessages(List);
      List.SaveToFile(Device.Name + '_outmsg.vmg');
    except
    end;

    try
      Label2.Caption := 'Back-Up Phone Book';
      Update;
      Application.ProcessMessages;
      BFSyncronizationClient.LoadPhoneBook(List);
      List.SaveToFile(Device.Name + '_pb.vcf');
    except
    end;

    BFSyncronizationClient.Close;
    Label1.Caption := 'Searching for device...';
    Label2.Caption := '';

  except
  end;

  List.Free;
end;

end.
